.. Copyright (C) 2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops.machine:

debops.machine
==============

.. include:: man_description.rst
   :start-line: 7

.. toctree::
   :maxdepth: 2

   getting-started
   defaults/main
   defaults-detailed

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/machine/COPYRIGHT

.. note:: Name of this role was based on the :file:`/etc/machine-info`
          configuration file, and is loosely connected to the concept of the
          "Machine" defined in the `Site Reliability Engineering`__ book.

.. __: https://landing.google.com/sre/book/chapters/production-environment.html

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
